@@ -6,7 +6,6 @@ package fakemachine
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path"
@@ -46,6 +45,11 @@ func (b umlBackend) Supported() (bool, error) {
 	if _, err := b.SlirpHelperPath(); err != nil {
 		return false, fmt.Errorf("libslirp-helper not installed")
 	}
+
+	// only support 512 bytes sector size
+	if b.machine.sectorSize != 512 {
+		return false, fmt.Errorf("uml backend only supports 512 bytes sector size")
+	}
 	return true, nil
 }
 
@@ -71,7 +75,7 @@ func (b umlBackend) ModulePath() (string, error) {
 	}
 
 	// find the subdirectory containing the modules for the UML release
-	modSubdirs, err := ioutil.ReadDir(moddir)
+	modSubdirs, err := os.ReadDir(moddir)
 	if err != nil {
 		return "", err
 	}
