@@ -8,7 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"github.com/alessio/shellescape"
-	"io/ioutil"
+	"io"
 	"os"
 	"os/exec"
 	"path"
@@ -185,16 +185,17 @@ type image struct {
 }
 
 type Machine struct {
-	arch     Arch
-	backend  backend
-	mounts   []mountPoint
-	count    int
-	images   []image
-	memory   int
-	numcpus  int
-	showBoot bool
-	quiet    bool
-	Environ  []string
+	arch       Arch
+	backend    backend
+	mounts     []mountPoint
+	count      int
+	images     []image
+	memory     int
+	numcpus    int
+	sectorSize int
+	showBoot   bool
+	quiet      bool
+	Environ    []string
 
 	scratchsize int64
 	scratchpath string
@@ -211,7 +212,7 @@ func NewMachine() (*Machine, error) {
 // Create a new machine object
 func NewMachineWithBackend(backendName string) (*Machine, error) {
 	var err error
-	m := &Machine{memory: 2048, numcpus: runtime.NumCPU()}
+	m := &Machine{memory: 2048, numcpus: runtime.NumCPU(), sectorSize: 512}
 
 	var ok bool
 	if m.arch, ok = archMap[runtime.GOARCH]; !ok {
@@ -240,7 +241,7 @@ func NewMachineWithBackend(backendName string) (*Machine, error) {
 		m.AddVolume("/etc/ssl")
 	}
 
-	// Mounts for java VM configuration, especialy security policies
+	// Mounts for java VM configuration, especially security policies
 	matches, _ := filepath.Glob("/etc/java*")
 	for _, path := range matches {
 		stat, err := os.Stat(path)
@@ -496,6 +497,12 @@ func (m *Machine) SetNumCPUs(numcpus int) {
 	m.numcpus = numcpus
 }
 
+// SetSectorSize overrides the default sector size(512 bytes) for the image
+// exposed to the fakemachine
+func (m *Machine) SetSectorSize(sectorSize int) {
+	m.sectorSize = sectorSize
+}
+
 // SetShowBoot sets whether to show boot/console messages from the fakemachine.
 func (m *Machine) SetShowBoot(showBoot bool) {
 	m.showBoot = showBoot
@@ -566,7 +573,7 @@ func (m *Machine) generateModulesDep(w *writerhelper.WriterHelper, moddir string
 			deps[j] = deppath
 		}
 		output[i] = fmt.Sprintf("%s: %s", modpath, strings.Join(deps, " "))
-		i += 1
+		i++
 	}
 
 	path := path.Join(moddir, "modules.dep")
@@ -609,7 +616,7 @@ func (m *Machine) setupscratch() error {
 		return nil
 	}
 
-	tmpfile, err := ioutil.TempFile(m.scratchpath, "fake-scratch.img.")
+	tmpfile, err := os.CreateTemp(m.scratchpath, "fake-scratch.img.")
 	if err != nil {
 		return err
 	}
@@ -659,7 +666,7 @@ func (m *Machine) startup(command string, extracontent [][2]string) (int, error)
 		}
 	}
 
-	tmpdir, err := ioutil.TempDir("", "fakemachine-")
+	tmpdir, err := os.MkdirTemp("", "fakemachine-")
 	if err != nil {
 		return -1, err
 	}
@@ -902,7 +909,7 @@ func (m *Machine) startup(command string, extracontent [][2]string) (int, error)
 		return -1, err
 	}
 
-	exitstr, _ := ioutil.ReadAll(result)
+	exitstr, _ := io.ReadAll(result)
 	exitcode, err := strconv.Atoi(strings.TrimSpace(string(exitstr)))
 
 	if err != nil {
